@@ -1,4 +1,3 @@
-from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 try:
     from django.utils.importlib import import_module
@@ -11,6 +10,9 @@ except ImportError:
     twitter = None
 
 
+from biblion.conf import settings
+
+
 def can_tweet():
     creds_available = (hasattr(settings, "TWITTER_USERNAME") and
                        hasattr(settings, "TWITTER_PASSWORD"))
